@@ -2,7 +2,7 @@ use 5.006;
 use strict;
 use warnings;
 package CPAN::Meta::Converter;
-our $VERSION = '2.120920'; # VERSION
+our $VERSION = '2.130870'; # VERSION
 
 
 use CPAN::Meta::Validator;
@@ -307,7 +307,7 @@ sub _is_module_name {
 }
 
 sub _clean_version {
-  my ($element, $key, $meta, $to_version) = @_;
+  my ($element) = @_;
   return 0 if ! defined $element;
 
   $element =~ s{^\s*}{};
@@ -676,12 +676,10 @@ sub _release_status_from_version {
 
 my $provides_spec = {
   file => \&_keep,
-  version => \&_clean_version,
 };
 
 my $provides_spec_2 = {
   file => \&_keep,
-  version => \&_clean_version,
   ':custom'  => \&_prefix_custom,
 };
 
@@ -692,6 +690,8 @@ sub _provides {
   my $new_data = {};
   for my $k ( keys %$element ) {
     $new_data->{$k} = _convert($element->{$k}, $spec, $to_version);
+    $new_data->{$k}{version} = _clean_version($element->{$k}{version})
+      if exists $element->{$k}{version};
   }
   return $new_data;
 }
@@ -1260,17 +1260,19 @@ sub convert {
 
 # ABSTRACT: Convert CPAN distribution metadata structures
 
-
+__END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.120920
+version 2.130870
 
 =head1 SYNOPSIS
 
@@ -1378,6 +1380,64 @@ Ricardo Signes <rjbs@cpan.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Ansgar Burchardt <ansgar@cpan.org>
+
+=item *
+
+Michael G. Schwern <mschwern@cpan.org>
+
+=item *
+
+Randy Sims <randys@thepierianspring.org>
+
+=item *
+
+Ævar Arnfjörð Bjarmason <avar@cpan.org>
+
+=item *
+
+Christopher J. Madsen <cjm@cpan.org>
+
+=item *
+
+Cory G Watson <gphat@cpan.org>
+
+=item *
+
+Damyan Ivanov <dam@cpan.org>
+
+=item *
+
+Eric Wilhelm <ewilhelm@cpan.org>
+
+=item *
+
+Gregor Hermann <gregoa@debian.org>
+
+=item *
+
+Ken Williams <kwilliams@cpan.org>
+
+=item *
+
+Lars Dɪᴇᴄᴋᴏᴡ 迪拉斯 <daxim@cpan.org>
+
+=item *
+
+Leon Timmermans <leont@cpan.org>
+
+=item *
+
+Mark Fowler <markf@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by David Golden and Ricardo Signes.
@@ -1386,8 +1446,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
